@@ -75,6 +75,9 @@ def serialize_bloom_filter_config(config: BloomFilterConfig) -> Dict:
     if config.charset is not None:
         d["charset"] = config.charset
 
+    if config.filter_type is not None:
+        d["filterType"] = config.filter_type
+
     if config.hash_strategy is not None:
         d["hashStrategy"] = config.hash_strategy
 
